@@ -233,6 +233,7 @@ impl TryFrom<AccessTokenResponse> for AccessToken {
 mod tests {
     use crate::{
         GetProfileRequest, GetTopicRequest, ScoopitAPIClient, SearchRequest, SearchRequestType,
+        TestRequest,
     };
 
     async fn get_client() -> ScoopitAPIClient {
@@ -274,6 +275,16 @@ mod tests {
         println!("{:#?}", topic);
     }
 
+    #[tokio::test]
+    async fn get_test() {
+        let response = get_client()
+            .await
+            .get(TestRequest::default())
+            .await
+            .unwrap();
+        println!("{:#?}", response);
+    }
+
     #[tokio::test]
     async fn search() {
         let client = get_client().await;
